/*******************************************************************************
 *                                                                             *
 *   F1LT - unofficial Formula 1 live timing application                       *
 *   Copyright (C) 2012-2013  Mariusz Pilarek (pieczaro@gmail.com)             *
 *                                                                             *
 *   This program is free software: you can redistribute it and/or modify      *
 *   it under the terms of the GNU General Public License as published by      *
 *   the Free Software Foundation, either version 3 of the License, or         *
 *   (at your option) any later version.                                       *
 *                                                                             *
 *   This program is distributed in the hope that it will be useful,           *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *   GNU General Public License for more details.                              *
 *                                                                             *
 *   You should have received a copy of the GNU General Public License         *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
 *                                                                             *
 *******************************************************************************/

#ifndef DRIVERRADARAREA_H
#define DRIVERRADARAREA_H

#include <QGraphicsObject>
#include "driverradarpositioner.h"

namespace DriverTrackerTool
{

class DriverRadarArea : public QGraphicsObject
{
    Q_OBJECT
public:
    explicit DriverRadarArea(QGraphicsItem *parent = 0);

    QRectF boundingRect () const;
    void paint (QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);

    void setup(int speed);

    void updatePosition();

    void checkSetupCorrect(int speed);
    void loadDriversList();

    void setSpeed(int speed)
    {
        for (int i = 0; i < drp.size(); ++i)
            drp[i]->setSpeed(speed);
    }


    void setViewRotation(int rotation)
    {
        for (int i = 0; i < drp.size(); ++i)
            drp[i]->setViewRotation(rotation);
    }

    void setViewScale(double scale)
    {
        for (int i = 0; i < drp.size(); ++i)
            drp[i]->setViewScale(scale);
    }

    void updateSize(int width);
    
signals:
    void driverSelected(int id);
    
public slots:

    void onDRDriverSelected(DriverRadarPositioner *driver);
    void selectDriver(int id);
    void excludeDriver(int id, bool exclude);

private:
    QVector<DriverRadarPositioner*> drp;

    int selectedDriver;

    int radarX, radarY;
    double radarR;
    double radarPitR;
    double radarLappedR;
    
};

}
#endif // DRIVERRADARAREA_H
