/*******************************************************************************
 *                                                                             *
 *   F1LT - unofficial Formula 1 live timing application                       *
 *   Copyright (C) 2012-2013  Mariusz Pilarek (pieczaro@gmail.com)             *
 *                                                                             *
 *   This program is free software: you can redistribute it and/or modify      *
 *   it under the terms of the GNU General Public License as published by      *
 *   the Free Software Foundation, either version 3 of the License, or         *
 *   (at your option) any later version.                                       *
 *                                                                             *
 *   This program is distributed in the hope that it will be useful,           *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *   GNU General Public License for more details.                              *
 *                                                                             *
 *   You should have received a copy of the GNU General Public License         *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
 *                                                                             *
 *******************************************************************************/


#ifndef DRIVERRADARSCENE_H
#define DRIVERRADARSCENE_H

#include <QDebug>
#include <QGraphicsScene>
#include <QVector>
#include <QWidget>

#include "driverradararea.h"
#include "driverradarpositioner.h"
#include "drivertrackerinfo.h"

#include "../../core/eventdata.h"

namespace DriverTrackerTool
{

class DriverRadarScene : public QGraphicsScene
{
    Q_OBJECT
public:
    explicit DriverRadarScene(QObject *parent = 0);
    virtual ~DriverRadarScene();
           
    virtual void loadDriversList();
    virtual void setupDrivers(int speed);

    virtual void checkSetupCorrect(int speed)
    {
        radar->checkSetupCorrect(speed);
        updateSize();
    }

    void setSpeed(int speed)
    {
        radar->setSpeed(speed);
    }

    void rotate(int currentAngle, int totalAngle)
    {
        radar->rotate(currentAngle);
        radar->setViewRotation(totalAngle);
    }

    void scale(double currentScale, double totalScale)
    {
        radar->scale(currentScale, currentScale);
        radar->setViewScale(totalScale);
    }

    void updatePosition()
    {
        radar->updatePosition();
//        driverClassificaction->update();
    }

public slots:
    void selectDriver(int id)
    {
        radar->selectDriver(id);
        dtInfo->setDriver(id);
    }

    void excludeDriver(int id, bool exclude)
    {
        radar->excludeDriver(id, exclude);
    }

    void updateSize();

    void sessionTimerUpdated()
    {
        dtInfo->update();
    }

signals:

    void driverSelected(int);
    void driverSelected(DriverRadarPositioner*);

protected:

    bool isExcluded(int id);


    QList<int> excludedDrivers;

    QVector<DriverRadarPositioner*> drp;

    int selectedDriver;

//    DriverTrackerInfo *dti;

private:    
    int radarX, radarY;
    double radarR;
    double radarPitR;
    double radarLappedR;

    DriverRadarArea *radar;
    DriverTrackerInfo *dtInfo;
};

}
#endif // DRIVERRADARSCENE_H
