/*******************************************************************************
 *                                                                             *
 *   F1LT - unofficial Formula 1 live timing application                       *
 *   Copyright (C) 2012-2013  Mariusz Pilarek (pieczaro@gmail.com)             *
 *                                                                             *
 *   This program is free software: you can redistribute it and/or modify      *
 *   it under the terms of the GNU General Public License as published by      *
 *   the Free Software Foundation, either version 3 of the License, or         *
 *   (at your option) any later version.                                       *
 *                                                                             *
 *   This program is distributed in the hope that it will be useful,           *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *   GNU General Public License for more details.                              *
 *                                                                             *
 *   You should have received a copy of the GNU General Public License         *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
 *                                                                             *
 *******************************************************************************/

#ifndef DRIVERTRACKERAREA_H
#define DRIVERTRACKERAREA_H

#include <QGraphicsObject>

#include <QGraphicsSceneMouseEvent>
#include "drivertrackerpositioner.h"

namespace DriverTrackerTool
{

class DriverTrackerArea : public QGraphicsObject
{
    Q_OBJECT
public:
    explicit DriverTrackerArea(QGraphicsItem *parent = 0);

    QRectF boundingRect () const;
    void paint (QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);

    void setup(int speed);

    void updatePosition();

    void checkSetupCorrect(int speed);
    void loadDriversList();

    void setSpeed(int speed)
    {
        for (int i = 0; i < dtp.size(); ++i)
            dtp[i]->setSpeed(speed);
    }


    void setViewRotation(int rotation)
    {
        for (int i = 0; i < dtp.size(); ++i)
            dtp[i]->setViewRotation(rotation);
    }

    void setViewScale(double scale)
    {
        for (int i = 0; i < dtp.size(); ++i)
            dtp[i]->setViewScale(scale);
    }

    void updateAll()
    {
        for (int i = 0; i < dtp.size(); ++i)
            dtp[i]->update();
    }

    DriverTrackerPositioner *getSelectedDriver();

signals:
    void driverSelected(int);

protected:
    void mousePressEvent(QGraphicsSceneMouseEvent *event);

public slots:
    void onDTPDriverSelected(DriverTrackerPositioner *driver);
    void selectDriver(int id);
    void excludeDriver(int id, bool exclude);

private:
    QPixmap trackMap;    
    QVector<DriverTrackerPositioner*> dtp;

    int selectedDriver;
};

}
#endif // DRIVERTRACKERAREA_H
