/*******************************************************************************
 *                                                                             *
 *   F1LT - unofficial Formula 1 live timing application                       *
 *   Copyright (C) 2012-2013  Mariusz Pilarek (pieczaro@gmail.com)             *
 *                                                                             *
 *   This program is free software: you can redistribute it and/or modify      *
 *   it under the terms of the GNU General Public License as published by      *
 *   the Free Software Foundation, either version 3 of the License, or         *
 *   (at your option) any later version.                                       *
 *                                                                             *
 *   This program is distributed in the hope that it will be useful,           *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *   GNU General Public License for more details.                              *
 *                                                                             *
 *   You should have received a copy of the GNU General Public License         *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
 *                                                                             *
 *******************************************************************************/


#ifndef DRIVERTRACKERSCENE_H
#define DRIVERTRACKERSCENE_H

#include <QDebug>
#include <QGraphicsScene>
#include <QGraphicsSceneWheelEvent>
#include <QPixmap>
#include "drivertrackerarea.h"
#include "driverclassification.h"

namespace DriverTrackerTool
{

class DriverTrackerScene : public QGraphicsScene
{
    Q_OBJECT

public:
    DriverTrackerScene(QObject *parent = 0);

    virtual void loadDriversList();
    virtual void setupDrivers(int speed);

    virtual void checkSetupCorrect(int speed)
    {
        track->checkSetupCorrect(speed);        
        track->updateAll();
        setTrackPosition();
        setSceneRect(sceneBoundingRect());
    }

    void setSpeed(int speed)
    {
        track->setSpeed(speed);
    }

    void setDrawDriverClassification(bool val)
    {
        drawClassification = val;
//        setup();
    }
    bool drawDriverClassification()
    {
        return drawClassification;
    }

    void rotate(int currentAngle, int totalAngle)
    {
        track->rotate(currentAngle);
        track->setViewRotation(totalAngle);

        setTrackPosition();
        setSceneRect(sceneBoundingRect());
    }

    void scale(double currentScale, double totalScale)
    {
        track->scale(currentScale, currentScale);
        track->setViewScale(totalScale);

        setTrackPosition();
        setSceneRect(sceneBoundingRect());
    }

    void setTrackPosition()
    {
        track->setPos(driverClassificaction->x() + (driverClassificaction->boundingRect().width() + track->boundingRect().width())/2 + 50, 0);
        int x = track->boundingRect().x();

        if (x <= (driverClassificaction->boundingRect().x() + driverClassificaction->boundingRect().width()/2))
            track->setPos(driverClassificaction->x() + (driverClassificaction->boundingRect().width() + track->sceneBoundingRect().width())/2 + 50, 0);
    }

    //returns bounding rect of all scene items
    QRectF sceneBoundingRect()
    {
        QRectF rect = driverClassificaction->sceneBoundingRect();

        rect.setWidth(rect.width() + 50 + track->sceneBoundingRect().width());

        qreal h = driverClassificaction->sceneBoundingRect().height();
        qreal y = driverClassificaction->sceneBoundingRect().y();

        if (h < track->sceneBoundingRect().height())
        {
            h = track->sceneBoundingRect().height();
            y = track->sceneBoundingRect().y();
        }
        rect.setY(y);
        rect.setHeight(h);

        return rect;
    }

    void updatePosition()
    {
        track->updatePosition();
//        driverClassificaction->update();
    }

    DriverTrackerPositioner *getSelectedDriver()
    {
        return track->getSelectedDriver();
    }

    void resetView()
    {
        track->resetMatrix();
        driverClassificaction->resetMatrix();

        setSceneRect(sceneBoundingRect());
    }

public slots:
    void selectDriver(int id)
    {
        track->selectDriver(id);
        driverClassificaction->selectDriver(id);
    }

    void sessionTimerUpdated()
    {
        driverClassificaction->update();
    }

signals:

    void driverSelected(int);
    void driverSelected(DriverTrackerPositioner*);
    void driverExcluded(int, bool);
    void viewScaled(int);

protected:

    void wheelEvent(QGraphicsSceneWheelEvent *event);

    bool isExcluded(int id);


    QList<int> excludedDrivers;

    bool drawClassification;

    DriverTrackerArea *track;
    DriverClassification *driverClassificaction;
};

}
#endif // DRIVERTRACKERSCENE_H
